%global _hardened_build 1
# for better compatibility with SCL spec file
%global pkg_name mongodb
# mongod daemon
%global daemon mongod
# mongos daemon
%global daemonshard mongos

Name:    mongodb
Version: 3.2.5
Release: %mkrel 3
Summary: MongoDB client shell and tools
License: AGPL 3.0
URL: http://www.mongodb.org
Group: Databases
Source0: http://downloads.mongodb.org/src/%{name}-src-r%{version}.tar.gz
Source1:        %{pkg_name}-tmpfile
Source2:        %{pkg_name}.logrotate
Source3:        %{daemon}.conf
Source5:        %{daemon}.service
Source6:        %{daemon}.sysconf
Source7:        %{daemonshard}.conf
Source9:        %{daemonshard}.service
Source10:       %{daemonshard}.sysconf
Source11:       %{pkg_name}-sysusers
Source12:	mozjs-38-arm.tbz2

# Enable building with system version of libraries
# https://jira.mongodb.org/browse/SERVER-21353
Patch0:         system-libs.patch

#Patch1: mongodb-src-r2.4.6-GCC_4.8.patch
BuildRequires: js-devel
BuildRequires: readline-devel
BuildRequires: boost-devel >= 1.58
BuildRequires: pcrecpp-devel
BuildRequires: libsasl-devel
BuildRequires: pcap-devel
BuildRequires: zlib-devel
BuildRequires: pkgconfig(yaml-cpp)
BuildRequires: scons
BuildRequires: google-perftools-devel
BuildRequires: snappy-devel
BuildRequires: openssl-devel
BuildRequires: libstemmer-devel
BuildRequires: valgrind-devel

# Needs at least std::current_exception
ExcludeArch:   armv5tl

%description
Mongo (from "huMONGOus") is a schema-free document-oriented database.
It features dynamic profileable queries, full indexing, replication
and fail-over support, efficient storage of large binary data objects,
and auto-sharding.

This package provides the mongo shell, import/export tools, and other
client utilities.

%package server
Summary: MongoDB server, sharding server, and support scripts
Group: Databases
Requires: mongodb
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1


%description server
Mongo (from "huMONGOus") is a schema-free document-oriented database.

This package provides the mongo server software, mongo sharding server
softwware, default configuration files, and init.d scripts.


%package devel
Summary: MongoDB server, sharding server, and support scripts
Group: Databases
Requires: mongodb

%description devel
This package provides the devel files for %{name}.

%prep
%setup -qn %{name}-src-r%{version} -a12
%autopatch -p1

# CRLF -> LF
sed -i 's/\r//' README

# disable propagation of $TERM env var into the Scons build system
sed -i -r "s|(for key in \('HOME'), 'TERM'(\):)|\1\2|" SConstruct

# Use system versions of header files (bundled does not differ)
sed -i -r "s|third_party/libstemmer_c/include/libstemmer.h|libstemmer/libstemmer.h|" src/mongo/db/fts/stemmer.h
sed -i -r "s|third_party/yaml-cpp-0.5.1/include/yaml-cpp/yaml.h|yaml-cpp/yaml.h|" src/mongo/util/options_parser/options_parser.cpp

# by default use system mongod, mongos and mongo binaries
sed -i -r "s|(default=os.path.join\()mongo_repo(, 'mongod'\))|\1'%{_bindir}'\2|"   buildscripts/smoke.py
sed -i -r "s|(default=os.path.join\()mongo_repo(, 'mongo'\))|\1'%{_bindir}'\2|"    buildscripts/smoke.py
sed -i -r "s|(os.path.join\()mongo_repo(, program)|\1'%{_bindir}'\2|"              buildscripts/smoke.py

# set default data prefix
sed -i -r "s|(smoke_db_prefix = ')'|\1var'|"                           buildscripts/smoke.py
sed -i -r "s|^([[:space:]]*)(set_globals\(options, tests\))$|\1\2\n\1global failfile\n\1\
failfile = os.path.join\(os.path.join\(mongo_repo, smoke_db_prefix\), 'failfile.smoke'\)|"    buildscripts/smoke.py

# Disable optimization for s2 library
# https://jira.mongodb.org/browse/SERVER-17511
sed -i -r "s|(env.Append\(CCFLAGS=\['-DDEBUG_MODE=false')(\]\))|\1,'-O0'\2|"  src/third_party/s2/SConscript

%build
%serverbuild
%scons all --prefix=%{_prefix} --mute=True \
       --use-system-pcre=True \
       --use-system-boost=True \
       --use-system-zlib=True \
       --use-system-yaml=True \
       --use-system-tcmalloc=True \
       --use-system-snappy=True \
       --use-system-valgrind=True \
       --use-system-stemmer=True \
       --nostrip \
       --ssl \
       --disable-warnings-as-errors \
%ifarch x86_64
        --wiredtiger=on \
%else
	--wiredtiger=off \
%endif
        --experimental-decimal-support=off \
       CCFLAGS="%{?optflags} -DBOOST_OPTIONAL_USE_OLD_DEFINITION_OF_NONE" LINKFLAGS="%{?__global_ldflags}"

%install
%serverbuild
%scons install --prefix=%{buildroot}%{_prefix} --mute=True \
       --use-system-pcre=True \
       --use-system-boost=True \
       --use-system-zlib=True \
       --use-system-yaml=True \
       --use-system-tcmalloc=True \
       --use-system-snappy=True \
       --use-system-valgrind=True \
       --use-system-stemmer=True \
       --nostrip \
       --ssl \
       --disable-warnings-as-errors \
%ifarch x86_64
        --wiredtiger=on \
%else
	--wiredtiger=off \
%endif
        --experimental-decimal-support=off \
       CCFLAGS="%{?optflags}  -DBOOST_OPTIONAL_USE_OLD_DEFINITION_OF_NONE" LINKFLAGS="%{?__global_ldflags}"

mkdir -p %{buildroot}%{_sharedstatedir}/%{pkg_name}
mkdir -p %{buildroot}%{_localstatedir}/log/%{pkg_name}
mkdir -p %{buildroot}%{_localstatedir}/run/%{pkg_name}
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig

install -p -D -m 644 "%{SOURCE1}"  %{buildroot}%{_tmpfilesdir}/%{pkg_name}.conf
install -p -D -m 644 "%{SOURCE5}"  %{buildroot}%{_unitdir}/%{daemon}.service
install -p -D -m 644 "%{SOURCE9}"  %{buildroot}%{_unitdir}/%{daemonshard}.service
install -p -D -m 644 "%{SOURCE2}"  %{buildroot}%{_sysconfdir}/logrotate.d/%{pkg_name}
install -p -D -m 644 "%{SOURCE3}"  %{buildroot}%{_sysconfdir}/%{daemon}.conf
install -p -D -m 644 "%{SOURCE7}"  %{buildroot}%{_sysconfdir}/%{daemonshard}.conf
install -p -D -m 644 "%{SOURCE6}"  %{buildroot}%{_sysconfdir}/sysconfig/%{daemon}
install -p -D -m 644 "%{SOURCE10}" %{buildroot}%{_sysconfdir}/sysconfig/%{daemonshard}
install -p -D -m 644 "%{SOURCE11}" %{buildroot}%{_prefix}/lib/sysusers.d/%{pkg_name}.conf

install -d -m 755                     %{buildroot}%{_mandir}/man1
install -p -m 644 debian/mongo.1      %{buildroot}%{_mandir}/man1/
install -p -m 644 debian/mongoperf.1  %{buildroot}%{_mandir}/man1/
install -p -m 644 debian/mongosniff.1 %{buildroot}%{_mandir}/man1/
install -p -m 644 debian/mongod.1     %{buildroot}%{_mandir}/man1/
install -p -m 644 debian/mongos.1     %{buildroot}%{_mandir}/man1/

rm -f %{buildroot}/usr/lib/libmongoclient.a

%post server
# (cg) Make sure the pid folder exists on install
/usr/bin/systemd-sysusers mongodb.conf
%_tmpfilescreate mongodb
%_post_service mongod

%preun server
%_preun_service mongod

%postun server
%_postun_userdel mongod

%files
%doc README GNU-AGPL-3.0.txt
%{_bindir}/mongo
%{_bindir}/mongoperf
%{_bindir}/mongosniff
%{_mandir}/man1/mongo.1*
%{_mandir}/man1/mongosniff.1*
%{_mandir}/man1/mongoperf.1.*

%files server
%{_bindir}/mongod
%{_bindir}/mongos
%{_mandir}/man1/mongod.1*
%{_mandir}/man1/mongos.1*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{pkg_name}
%config(noreplace) %{_sysconfdir}/%{daemon}.conf
%config(noreplace) %{_sysconfdir}/%{daemonshard}.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{daemon}
%config(noreplace) %{_sysconfdir}/sysconfig/%{daemonshard}
%ghost %{_sharedstatedir}/%{pkg_name}
%ghost %{_localstatedir}/run/%{pkg_name}
%ghost %{_localstatedir}/log/%{pkg_name}
%ghost %{_localstatedir}/lib/%{pkg_name}
%{_prefix}/lib/sysusers.d/%{pkg_name}.conf
%{_tmpfilesdir}/%{pkg_name}.conf
%{_unitdir}/*.service


%changelog
* Thu Jul 21 2016 pterjan <pterjan> 3.2.5-3.mga6
+ Revision: 1042964
- Clean fix for js build on arm
- Fix arm more

* Thu Jul 21 2016 pterjan <pterjan> 3.2.5-2.mga6
+ Revision: 1042953
- Fix build on arm

* Sun Apr 24 2016 joequant <joequant> 3.2.5-1.mga6
+ Revision: 1005896
- upgrade to 3.2.5

* Thu Mar 31 2016 pterjan <pterjan> 3.2.0-4.mga6
+ Revision: 996986
- Exclude from armv5tl which does not have std::current_exception

* Wed Mar 02 2016 umeabot <umeabot> 3.2.0-3.mga6
+ Revision: 983685
- Rebuild for openssl

* Fri Jan 01 2016 joequant <joequant> 3.2.0-2.mga6
+ Revision: 917667
- upgrade to 3.2.0

* Sat Dec 26 2015 daviddavid <daviddavid> 3.0.7-2.mga6
+ Revision: 915390
- rebuild for new boost 1.60.0

* Wed Oct 28 2015 joequant <joequant> 3.0.7-1.mga6
+ Revision: 896010
- upgrade to 3.0.7

* Sat Sep 26 2015 daviddavid <daviddavid> 3.0.5-7.mga6
+ Revision: 883949
- rebuild for new boost 1.59.0

* Mon Aug 24 2015 joequant <joequant> 3.0.5-6.mga6
+ Revision: 868883
- recompile with new boost

* Tue Aug 04 2015 joequant <joequant> 3.0.5-5.mga6
+ Revision: 861106
- fix up sysusers

* Tue Aug 04 2015 joequant <joequant> 3.0.5-4.mga6
+ Revision: 861063
- add comment to insert login.defs
- use dynamic ranges for mongodb-sysusers

* Tue Aug 04 2015 joequant <joequant> 3.0.5-3.mga6
+ Revision: 861001
- change to use sysusers and tmpfile

* Tue Aug 04 2015 joequant <joequant> 3.0.5-2.mga6
+ Revision: 860953
- fix up startup scripts
- fix run file
- fix mongo installation

* Fri Jul 31 2015 joequant <joequant> 3.0.5-1.mga6
+ Revision: 859333
- upgrade to 3.0.5
- remove check for now

* Mon Mar 30 2015 luigiwalser <luigiwalser> 2.4.9-4.mga5
+ Revision: 819418
- add upstream patch to fix CVE-2015-1609

* Wed Oct 15 2014 umeabot <umeabot> 2.4.9-3.mga5
+ Revision: 750223
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.4.9-2.mga5
+ Revision: 682569
- Mageia 5 Mass Rebuild

* Sat Feb 22 2014 dlucio <dlucio> 2.4.9-1.mga5
+ Revision: 595422
- 2.4.9

* Sat Feb 15 2014 philippem <philippem> 2.4.6-4.mga5
+ Revision: 591868
- use _tmpfilescreate
- set {_sysconfdir}/sysconfig/mongod config(noreplace)

* Sat Feb 08 2014 barjac <barjac> 2.4.6-3.mga5
+ Revision: 586736
- rebuild against boost-1.55

* Mon Oct 21 2013 umeabot <umeabot> 2.4.6-2.mga4
+ Revision: 537838
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 sander85 <sander85> 2.4.6-1.mga4
+ Revision: 487928
- New version: 2.4.6
- Fix build with GCC 4.8

* Wed Jul 10 2013 fwang <fwang> 2.4.5-2.mga4
+ Revision: 452415
- update file list
- update file list
- update file list
- rebuild for new boost
- drop old initscript

  + oden <oden>
    - 2.4.5 (fixes CVE-2013-4650)

* Wed Jun 26 2013 fwang <fwang> 2.4.4-1.mga4
+ Revision: 446780
- specify build options when installing
- fix build with recent boost
- build with pcrecpp
- use system libs
- update file list
- new version 2.4.4

* Tue Apr 09 2013 luigiwalser <luigiwalser> 2.2.2-3.mga3
+ Revision: 409193
- add patch from fedora to fix CVE-2013-1892

* Sat Jan 12 2013 umeabot <umeabot> 2.2.2-2.mga3
+ Revision: 360211
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 2.2.2-1.mga3
+ Revision: 324139
- new version 2.2.2

* Mon Sep 03 2012 fedya <fedya> 2.2.0-1.mga3
+ Revision: 287631
- unpackaged files devel section added
- version update 2.2.0

* Tue Aug 28 2012 fwang <fwang> 2.0.7-1.mga3
+ Revision: 284938
- new version 2.0.7
- use default filesystem version
- rebuild for new boost

* Sun Jun 10 2012 fwang <fwang> 2.0.6-1.mga3
+ Revision: 259266
- new version 2.0.6

* Wed May 30 2012 fwang <fwang> 2.0.3-5.mga3
+ Revision: 249654
- rebuild for new boost

* Sat Apr 28 2012 tmb <tmb> 2.0.3-4.mga2
+ Revision: 233791
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sun Apr 22 2012 colin <colin> 2.0.3-3.mga2
+ Revision: 232648
- Future proof creation of pid folder via tmpfiles.d

* Sun Apr 22 2012 colin <colin> 2.0.3-2.mga2
+ Revision: 232641
- Add systemd support

* Fri Mar 02 2012 fwang <fwang> 2.0.3-1.mga2
+ Revision: 216624
- new version 2.0.3

* Fri Dec 16 2011 fwang <fwang> 2.0.2-1.mga2
+ Revision: 182401
- new version 2.0.2

* Mon Nov 28 2011 fwang <fwang> 2.0.1-2.mga2
+ Revision: 173614
- rebuild for new boost

* Wed Nov 02 2011 fwang <fwang> 2.0.1-1.mga2
+ Revision: 161545
- new version 2.0.1

* Sat Sep 17 2011 fwang <fwang> 2.0.0-1.mga2
+ Revision: 144569
- update file list
- new version 2.0.0

* Sat Sep 03 2011 fwang <fwang> 1.8.3-1.mga2
+ Revision: 138125
- new version 1.9.3
- rebuild for new boost

* Wed Jun 22 2011 fwang <fwang> 1.8.2-1.mga2
+ Revision: 111869
- new version 1.8.2

* Sat Mar 26 2011 dmorgan <dmorgan> 1.6.5-2.mga1
+ Revision: 77586
- imported package mongodb

